@@ -78,8 +78,9 @@
 #' \eqn{e^{O2}_{it}} in \cite{Touloumis (2016)}.}
 #' @author Anestis Touloumis
 #' @seealso \code{\link{rmult.bcl}} for simulating correlated nominal
-#' responses, \code{\link{rmult.clm}} for simulating correlated ordinal
-#' responses and \code{\link{rbin}} for simulating correlated binary responses.
+#' responses, \code{\link{rmult.clm}} and \code{\link{rmult.acl}} for simulating
+#' correlated ordinal responses and \code{\link{rbin}} for simulating
+#' correlated binary responses.
 #' @references Cario, M. C. and Nelson, B. L. (1997) \emph{Modeling and
 #' generating random vectors with arbitrary marginal distributions and
 #' correlation matrix}. Technical Report, Department of Industrial Engineering
@@ -98,38 +99,49 @@
 #' @examples
 #' ## See Example 3.3 in the Vignette.
 #' set.seed(1)
-#' N <- 500
-#' clsize <- 4
-#' intercepts <- c(-1.5, -0.5, 0.5, 1.5)
-#' betas <- 1
-#' x <- rnorm(N * clsize)
-#' ncategories <- 5
-#' cor.matrix <- diag(1, (ncategories - 1) * clsize) + kronecker(toeplitz(c(0,
-#'     rep(0.24, ncategories - 2))), matrix(1, clsize, clsize))
-#' CorOrdRes <- rmult.crm(clsize = clsize, intercepts = intercepts, betas = betas,
-#'     xformula = ~x, cor.matrix = cor.matrix, link = 'probit')
-#' head(CorOrdRes$Ysim)
-#'
-#'@export
-rmult.crm <- function(clsize = clsize, intercepts = intercepts, betas = betas,
-    xformula = formula(xdata), xdata = parent.frame(), link = "logit",
-    cor.matrix = cor.matrix, rlatent = NULL) {
+#' sample_size <- 500
+#' cluster_size <- 4
+#' beta_intercepts <- c(-1.5, -0.5, 0.5, 1.5)
+#' beta_coefficients <- 1
+#' x <- rnorm(sample_size * cluster_size)
+#' categories_no <- 5
+#' identity_matrix <- diag(1, (categories_no - 1) * cluster_size)
+#' equicorrelation_matrix <- toeplitz(c(0, rep(0.24, categories_no - 2)))
+#' ones_matrix <- matrix(1, cluster_size, cluster_size)
+#' latent_correlation_matrix <- identity_matrix +
+#'   kronecker(equicorrelation_matrix, ones_matrix)
+#' simulated_ordinal_dataset <- rmult.crm(clsize = cluster_size,
+#'   intercepts = beta_intercepts, betas = beta_coefficients, xformula = ~x,
+#'   cor.matrix = latent_correlation_matrix, link = "probit")
+#' head(simulated_ordinal_dataset$Ysim)
+#' @export
+rmult.crm <- function(clsize = clsize, intercepts = intercepts, betas = betas, # nolint
+                      xformula = formula(xdata), xdata = parent.frame(), link = "logit", # nolintr
+                      cor.matrix = cor.matrix, rlatent = NULL) { # nolint
   check_cluster_size(clsize)
-  betas <- check_betas(betas, clsize)
-  lpformula <- check_xformula(xformula)
-  if (!is.environment(xdata))
-    xdata <- data.frame(na.omit(xdata))
-  lin_pred <- create_linear_predictor(betas, clsize, lpformula, xdata,
-                                      "rmult.clm")
-  R <- nrow(lin_pred)
-  intercepts <- check_intercepts(intercepts, clsize, "rmult.crm", R)
-  ncategories <- ncol(intercepts) / clsize + 1
-  lin_pred_extended <- t(apply(lin_pred, 1,
-                               function(x) rep(x, each = ncategories - 1)))
-  rlatent <- create_rlatent(rlatent, R, link, clsize, cor.matrix, "rmult.crm",
-                            ncategories)
-  Ysim <- apply_threshold(lin_pred_extended, rlatent, clsize, "rmult.crm",
-                          intercepts, ncategories)
-  create_output(Ysim, R, clsize, rlatent, lpformula, xdata, "rmult.crm",
-                ncategories)
+  beta_coefficients <- check_betas(betas, clsize)
+  linear_predictor_formula <- check_xformula(xformula)
+  if (!is.environment(xdata)) xdata <- data.frame(na.omit(xdata))
+  linear_predictor <- create_linear_predictor(
+    beta_coefficients, clsize, linear_predictor_formula, xdata, "rmult.clm"
+  )
+  sample_size <- nrow(linear_predictor)
+  beta_intercepts <- check_intercepts(
+    intercepts, clsize, "rmult.crm", sample_size
+  )
+  categories_no <- ncol(beta_intercepts) / clsize + 1
+  linear_predictor_extended <- t(apply(linear_predictor, 1, function(x)
+    rep(x, each = categories_no - 1)))
+  simulated_latent_responses <- create_rlatent(
+    rlatent, sample_size, link, clsize, cor.matrix, "rmult.crm", categories_no
+  )
+  simulated_ordinal_responses <- apply_threshold(
+    linear_predictor_extended, simulated_latent_responses, clsize, "rmult.crm",
+    beta_intercepts, categories_no
+  )
+  create_output(
+    simulated_ordinal_responses, sample_size, clsize,
+    simulated_latent_responses, linear_predictor_formula, xdata, "rmult.crm",
+    categories_no
+  )
 }
